pixel_to_binary_code

Function pixel_to_binary_code 

pub fn pixel_to_binary_code(pixel: &mut Rgb<u8>)
Converts a 24-bit RGB pixel from Gray Code to pure binary code as defined here

Example

let mut pixel = Rgb::<u8>([0b10011111, 0b00101001, 0b11111001]);

pixel_to_binary_code(&mut pixel);

assert_eq!(pixel, Rgb::<u8>([0b11101010, 0b00110001, 0b10101110]));

Arguments

This function takes in one argument:

  • pixel: &mut Rgb<u8> — The pixel to convert.

Panics

This function does not panic.

Errors

This function does not return errors.

Returns

This function returns (), the passed in pixel will be changed instead of constructing a new pixel.